@@ -1,4 +1,4 @@
-__version__ = "0.8.0"
-__homepage__ = "https://jose.authlib.org/"
+__version__ = "1.0.1"
+__homepage__ = "https://jose.authlib.org/en/"
 __author__ = "Hsiaoming Yang <me@lepture.com>"
 __license__ = "BSD-3-Clause"
